@@ -1,6 +1,5 @@
-import ctypes
-
-ctypes.windll.user32.SetProcessDPIAware()
+#import ctypes
+#ctypes.windll.user32.SetProcessDPIAware()
 import os
 import random
 import sys
@@ -9,14 +8,14 @@ import pygame.gfxdraw
 import pygame_gui as pg_g
 
 sys.path.insert(0, '../frontiersman')
-from gameboard.NodeRoads import *
-from gameboard.SettlementButtons import *
-from client.Bank import *
-from client import ClientHelper
-from client import Actions
-from client.CardPickerGui import CardPickerGui
-from client.TraderGui import TradeGui
-from client.GuiConstants import CARD_SIZE, SPACING
+from frontiersman.gameboard.NodeRoads import *
+from frontiersman.gameboard.SettlementButtons import *
+from frontiersman.client.Bank import *
+from frontiersman.client import ClientHelper
+from frontiersman.client import Actions
+from frontiersman.client.CardPickerGui import CardPickerGui
+from frontiersman.client.TraderGui import TradeGui
+from frontiersman.client.GuiConstants import CARD_SIZE, SPACING
 
 # todo move some of these to GuiConstants.py
 RESOLUTION = (1920, 1080)
@@ -852,16 +851,17 @@ class Client:
         )
 
     def initialize_gui(self):
+
         pygame.init()
         pygame.display.set_caption('Client')
-
+        os.chdir(os.path.dirname(__file__))
         font_size = 45
         self.font = pygame.font.SysFont('Comic Sans MS', font_size)
 
         self.game_window = pygame.display.set_mode(RESOLUTION, pygame.FULLSCREEN)
         # self.game_window = pygame.display.set_mode(RESOLUTION)
 
-        self.manager = pg_g.UIManager(RESOLUTION, 'frontiersman/themes/card_theme.json')
+        self.manager = pg_g.UIManager(RESOLUTION, os.path.join(os.path.dirname(__file__), '../themes/card_theme.json'))
         self.clock = pygame.time.Clock()
 
         # creates settlement polygon
@@ -891,7 +891,6 @@ class Client:
         ]
 
         base_path = os.path.dirname(__file__)
-
         self.object_textures = {
             'Board': pygame.image.load(os.path.join(base_path, '../assets/gameboard_grid_v4.png'))
         }
