@@ -13,10 +13,6 @@ class client:
 
 
 class server:
-    @staticmethod
-    def main(address='127.0.0.1', port=1233):
-        server(address, int(port))
-
     def __init__(self, host, port):
         sep = '\n'
 
@@ -179,10 +175,25 @@ class server:
             cli.socket.send(str.encode("quit\n"))
         ServerSocket.close()
 
+def main():
+    address='127.0.0.1'
+    port=1233
+    if(len(sys.argv)==3):
+        address=sys.argv[1]
+        try:
+            port=sys.argv[2]
+        except ValueError:
+            print("invalid port")
+        else:
+            server(address, int(port))
+    else:
+        print("please put the address and port of the server")
+    
 
-if __name__ == "__main__":
-    # host = '127.0.0.1'
-    # port = 1233
-    host = sys.argv[1]
-    port = int(sys.argv[2])
-    test = server(host, port)
+
+# if __name__ == "__main__":
+#     # host = '127.0.0.1'
+#     # port = 1233
+#     host = sys.argv[1]
+#     port = int(sys.argv[2])
+#     test = server(host, port)
